==> haskell-asn1-types-0.3.4-225-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 asn1-types
version:              0.3.4
visibility:           public
id:                   asn1-types-0.3.4-IVf19CYkui7fJCxkiCCfT
key:                  asn1-types-0.3.4-IVf19CYkui7fJCxkiCCfT
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-asn1
synopsis:             ASN.1 types
description:          ASN.1 standard types
category:             Data
abi:                  36609890ed810b9f285bb0be52a2596e
exposed:              True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String

import-dirs:          /usr/lib/ghc-9.4.8/site-local/asn1-types-0.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/asn1-types-0.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/asn1-types-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-asn1-types
hs-libraries:         HSasn1-types-0.3.4-IVf19CYkui7fJCxkiCCfT
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hourglass-0.2.12-E9Qbay6T3aQAYDg34HaHZT
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt

haddock-interfaces:   /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html:         /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-types-0.3.4-226-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-asn1-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 asn1-types
version:              0.3.4
visibility:           public
id:                   asn1-types-0.3.4-DN3pjFa9lt0F1KIwsBTzWI
key:                  asn1-types-0.3.4-DN3pjFa9lt0F1KIwsBTzWI
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-asn1
synopsis:             ASN.1 types
description:          ASN.1 standard types
category:             Data
abi:                  240f3430877e80a24bb58005aa45eb2a
exposed:              True
exposed-modules:
    Data.ASN1.BitArray Data.ASN1.OID Data.ASN1.Pretty Data.ASN1.Types
    Data.ASN1.Types.Lowlevel Data.ASN1.Types.String

import-dirs:          /usr/lib/ghc-9.4.8/site-local/asn1-types-0.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/asn1-types-0.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/asn1-types-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-asn1-types
hs-libraries:         HSasn1-types-0.3.4-DN3pjFa9lt0F1KIwsBTzWI
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    hourglass-0.2.12-BhuwanK7FZLC4O6mhlD1f0
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt

haddock-interfaces:   /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
haddock-html:         /usr/share/doc/haskell-asn1-types/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
